opossom.tissues: Example data set.
Description
A data set comprising of 12 selected human tissues.Usage
data(opossom.tissues)
Format
The data set is stored in RData (binary) format.Source
http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE7307Details
The data set was downloaded from Gene Expression Omnibus repository
(http://www.ncbi.nlm.nih.gov/geo, GEO accession no. GSE7307).
About 20,000 genes in more than 650 samples were measured using the Affymetrix
HGU133-Plus2 microarray. A subset of 12 selected tissues from different
categories is used as example data set for the oposSOM-package.