This function realizes the complete pipeline functionality: single gene
expression values are culstered to metagenes using a self-organizing map. Based
on these metagenes, visualizations (e.g. expression profiles), downstreaming
sample similarity analyses (e.g. hierarchical clustering, ICA) and functional
enrichment analyses are performed.
The results are given within a separate folder and can be browsed using the
summary HTML file.
Usage
opossom.run(env)
Arguments
env
the opossom environment created with opossom.new according to the users' preferences